@@ -81,11 +81,11 @@ impl IntoPy<PyObject> for TokenType {
 
 #[derive(Error, Debug)]
 pub enum ParsingError {
-    #[error("invalid JSON: {0}")]
+    #[error("{0}")]
     InvalidJson(String),
-    #[error("error due to limitation: ")]
+    #[error("Error due to limitation: {0}")]
     Limitation(String),
-    #[error("unknown error")]
+    #[error("Unknown error")]
     Unknown,
 }
 
@@ -149,7 +149,7 @@ impl RustTokenizer {
                         Err(e) => {
                             let index = slf.index;
                             return Err(PyValueError::new_err(format!(
-                                "Error while parsing at index {index}: {e}"
+                                "{e} at index {index}"
                             )));
                         }
                     }
@@ -170,7 +170,7 @@ impl RustTokenizer {
             Err(e) => {
                 let index = slf.index;
                 return Err(PyValueError::new_err(format!(
-                    "Error while parsing at index {index}: {e}"
+                    "{e} at index {index}"
                 )));
             }
         }
@@ -684,8 +684,19 @@ impl RustTokenizer {
     }
 }
 
+/// supports_bigint()
+/// --
+///
+/// Returns whether the current installation supports arbitrary-size integers.
+#[pyfunction]
+fn supports_bigint() -> PyResult<bool> {
+    Ok(int::supports_bigint())
+}
+
 #[pymodule]
 fn json_stream_rs_tokenizer(_py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_class::<RustTokenizer>()?;
+    m.add_wrapped(wrap_pyfunction!(supports_bigint))?;
+
     Ok(())
 }
